==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusTypuInformacjiDodatkowej;
import pl.topteam.dps.enums.TypInformacjiDodatkowej;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class InformacjaDodatkowa extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA.NAZWA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nazwa;

    /**
     * INFORMACJA_DODATKOWA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusTypuInformacjiDodatkowej status;

    /**
     * INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean pojedynczyWpis;

    /**
     * INFORMACJA_DODATKOWA.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypInformacjiDodatkowej typ;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA.NAZWA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INFORMACJA_DODATKOWA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return INFORMACJA_DODATKOWA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusTypuInformacjiDodatkowej getStatus() {
        return status;
    }

    /**
     * INFORMACJA_DODATKOWA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusTypuInformacjiDodatkowej status) {
        this.status = status;
    }

    /**
     * @return INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getPojedynczyWpis() {
        return pojedynczyWpis;
    }

    /**
     * INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     *
     * @param pojedynczyWpis
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPojedynczyWpis(Boolean pojedynczyWpis) {
        this.pojedynczyWpis = pojedynczyWpis;
    }

    /**
     * @return INFORMACJA_DODATKOWA.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypInformacjiDodatkowej getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypInformacjiDodatkowej typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowa other = (InformacjaDodatkowa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getPojedynczyWpis() == null ? other.getPojedynczyWpis() == null : this.getPojedynczyWpis().equals(other.getPojedynczyWpis()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getPojedynczyWpis() == null) ? 0 : getPojedynczyWpis().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", status=").append(status);
        sb.append(", pojedynczyWpis=").append(pojedynczyWpis);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/InformacjaDodatkowa.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusTypuInformacjiDodatkowej;
import pl.topteam.dps.enums.TypInformacjiDodatkowej;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class InformacjaDodatkowa extends GenericDPSObject {
    /**
     * INFORMACJA_DODATKOWA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * INFORMACJA_DODATKOWA.NAZWA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nazwa;

    /**
     * INFORMACJA_DODATKOWA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusTypuInformacjiDodatkowej status;

    /**
     * INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean pojedynczyWpis;

    /**
     * INFORMACJA_DODATKOWA.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypInformacjiDodatkowej typ;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return INFORMACJA_DODATKOWA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * INFORMACJA_DODATKOWA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return INFORMACJA_DODATKOWA.NAZWA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNazwa() {
        return nazwa;
    }

    /**
     * INFORMACJA_DODATKOWA.NAZWA
     *
     * @param nazwa
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNazwa(String nazwa) {
        this.nazwa = nazwa == null ? null : nazwa.trim();
    }

    /**
     * @return INFORMACJA_DODATKOWA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusTypuInformacjiDodatkowej getStatus() {
        return status;
    }

    /**
     * INFORMACJA_DODATKOWA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusTypuInformacjiDodatkowej status) {
        this.status = status;
    }

    /**
     * @return INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getPojedynczyWpis() {
        return pojedynczyWpis;
    }

    /**
     * INFORMACJA_DODATKOWA.POJEDYNCZY_WPIS
     *
     * @param pojedynczyWpis
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPojedynczyWpis(Boolean pojedynczyWpis) {
        this.pojedynczyWpis = pojedynczyWpis;
    }

    /**
     * @return INFORMACJA_DODATKOWA.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypInformacjiDodatkowej getTyp() {
        return typ;
    }

    /**
     * INFORMACJA_DODATKOWA.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypInformacjiDodatkowej typ) {
        this.typ = typ;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        InformacjaDodatkowa other = (InformacjaDodatkowa) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNazwa() == null ? other.getNazwa() == null : this.getNazwa().equals(other.getNazwa()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getPojedynczyWpis() == null ? other.getPojedynczyWpis() == null : this.getPojedynczyWpis().equals(other.getPojedynczyWpis()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNazwa() == null) ? 0 : getNazwa().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getPojedynczyWpis() == null) ? 0 : getPojedynczyWpis().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", nazwa=").append(nazwa);
        sb.append(", status=").append(status);
        sb.append(", pojedynczyWpis=").append(pojedynczyWpis);
        sb.append(", typ=").append(typ);
        sb.append("]");
        return sb.toString();
    }
}
